---
sidebar_position: 2
title: 'Art Team'
---

# Art Team

The Art Team plays a vital role in shaping the player's visual experience. However, under the current workflow, the team’s involvement is largely limited to executing asset requests—drawing images/animations based on lists provided by the GD team—without deeper integration into the game design process. While this has sufficed for basic visual delivery, it introduces several critical problems that directly impact both game quality and performance.

## ⚠️ Current Issues

### Lack of Game-Centric Art Knowledge
Art is created with little consideration for how it functions within the game engine or interacts with gameplay systems. As a result:
- Assets may be unoptimized, causing performance issues such as frame drops or memory overhead.
- Elements may appear visually appealing in isolation but fail to communicate clearly or read well on actual game canvases, especially across varying screen sizes.
- Animations may not conform to engine capabilities, requiring extra developer effort or rework.

### Disconnected from Gameplay Context
Artists often have no visibility into the player experience, level pacing, or interactive systems. This prevents them from:
- Suggesting improvements to asset usability or feedback clarity.
- Understanding how visual hierarchy affects UX/UI.
- Adjusting the style to support gameplay mood or genre conventions.

### Task-Only Mindset
The current process fosters a task completion mentality, where the focus is on finishing the checklist rather than contributing to the visual identity of the game. This leads to:
- Missed opportunities to propose stylistic direction or polish ideas.
- Low creative engagement and undervaluing of the art team's potential.
- Friction when design or dev teams require visual revisions the art team didn’t anticipate.

## ✅ Proposed Improvements

### Involve the Art Team in Pre-Production

- Include the Art Team in early concept meetings and kickoff sessions.
- Encourage the team to contribute ideas for visual themes, UI/UX direction, and animation styles.
- Allow artists to collaborate directly with GD and DEV to ensure alignment between artistic vision and gameplay systems.

### Build Awareness of Technical Game Art Principles

- Provide internal training or documentation on how art assets affect game engine performance (e.g., texture size, draw calls, overdraw).
- Introduce key optimization techniques such as:
    - 9-Slice Scaling for scalable UI
    - Sprite Atlases for efficient rendering
    - Tileable Textures and Modular Design for environments
    - Proper Pivot Point Positioning for accurate animation behavior
    - Texture Compression Awareness for specific platform (WEBP, DXT, PVRTC)
- Encourage artists to consider screen readability, resolution flexibility, and resource usage when creating assets.

### Adopt Game Engine as a Collaborative Tool

- Equip the Art Team to work directly with game engines (e.g., Cocos Creator, Unity) to test and review how their assets behave in-game.
- Allow artists to preview scenes, animations, and UI within the engine to catch visual or functional issues early.
- Encourage collaboration with developers and technical artists to optimize rendering and improve asset integration workflows.

By embedding the Art Team into the full development cycle and building their technical capabilities, the studio can achieve a more cohesive, scalable, and high-quality visual standard across all projects.