---
sidebar_position: 4
title: 'Game Dev Team'
---

# Game Developer Team

The Development team is responsible for implementing game features, integrating assets, and building the final product experience. While the current workflow supports small-scale casino-style games, it has become increasingly outdated and limiting—both in terms of team growth and technological capability. To evolve with industry standards and scale to more complex projects, the DEV team must adopt better tools, practices, and collaboration models.

## ⚠️ Current Issues

### 1. Improper Use of Project Management Tools
- Development tasks are currently managed through **OpenProject**, which is more suitable for PMs than for developers.
- This results in disjointed workflows, weak integration with version control, and lack of proper branching or merge request tracking.

### 2. Technological Stagnation
- The tech stack remains focused on traditional web-based casino game development.
- There's minimal effort to explore newer tools, platforms, or game engine advancements.
- Modern game architecture and optimization practices are underutilized.

### 3. Single-Developer Workflow Model
- Most games are built by a single developer from start to finish.
- There is limited collaboration, peer review, or code reuse.
- Knowledge silos form, and shared technical standards are difficult to enforce.

---

## ✅ Proposed Improvements

### 1. Use Gitea for Development-Centric Project Management
- Replace OpenProject with **Gitea** for handling:
  - Git repositories
  - Issue tracking
  - Branching strategy
  - Pull requests and code reviews
- This enables a more efficient and transparent development workflow.

### 2. Modernize Game Development Practices
- Encourage the team to:
  - Stay updated on current engine and framework capabilities (e.g., Unity, Cocos Creator, WebAssembly)
  - Learn and apply advanced architecture patterns: modularity, ECS, DI, plugin systems
  - Utilize tooling like **profilers**, **linting**, **CI/CD**, and **debugging environments**
- Dedicate R&D time to explore new platforms and technologies (e.g., mobile-native, multiplayer systems)

### 3. Shift Toward Collaborative Game Development
- Build small, multi-developer teams for selected projects.
- Promote practices such as:
  - Code review and pair programming
  - Shared libraries and reusable modules
  - Technical leadership and mentoring roles
- This encourages long-term scalability and continuous team learning.

---

By transforming the Development team’s process, toolset, and structure, the studio can better adapt to changing market needs, improve internal efficiency, and prepare for larger and more ambitious titles.