---
sidebar_position: 6
---

# References

The following sources and case studies support the concepts and challenges discussed in this proposal. They highlight real-world examples where workflow, collaboration, or documentation practices had a significant impact on project success or failure.

---

## 1. **Final Fantasy XIV – The Flower Pot Performance Issue**  
**Topic:** Technical misalignment between teams leading to unintended performance problems  

**Summary:**  
In Final Fantasy XIV, a seemingly simple feature—adding decorative flower pots to player housing—caused unexpected performance drops. The root cause was a lack of technical alignment between the **UI team** and the **engine/rendering team**. Each flower pot used the **same high-complexity shader** originally designed for **player characters**, drastically increasing the rendering load when multiple pots were placed.  

Although both teams produced high-quality work independently, their lack of shared technical constraints or collaborative review caused a massive increase in draw calls and shader complexity—resulting in degraded performance.

**Lesson:**  
This case illustrates that **two well-executed features built in isolation can combine to create a major issue**. Without shared technical planning, documentation alignment, or early review, even simple systems can clash in costly ways. Cross-team collaboration and engine-awareness are critical, especially when reusing core systems.

## 2. **Anthem – Design Vision vs. Technical Reality**  
**Topic:** Unrealistic design expectations and lack of technical alignment  

**Summary:**  
During early development, the design team for *Anthem* envisioned a world with **four large explorable cities**, each with unique environments, quests, and NPC ecosystems. This was part of their ambition to create a living, dynamic sci-fi world. However, the team failed to properly validate whether this vision was technically feasible in the chosen engine (Frostbite)—an engine known to be inflexible and poorly suited for large-scale RPG world-building.

As development progressed, it became clear that:
- The engine **could not support multiple large city hubs** due to memory constraints, loading issues, and performance bottlenecks.
- There was **no clear communication** between designers and engine programmers early enough to adapt the design accordingly.
- Instead of iterating or compromising gradually, the team had to **cut the entire plan down to a single city (Fort Tarsis)** late in development.

This resulted in:
- Wasted development time and resources
- Broken expectations for both the design team and leadership
- A final product that felt much smaller and more static than initially promised

**Lesson:**  
This highlights the risk of building ambitious game designs in isolation without consulting engineering or testing feasibility early. **Good design ideas are only successful when grounded in technical reality and validated collaboratively** across departments.

## 3. **Hades – Success Through Iteration and Cross-Team Collaboration**  
**Topic:** Effective design-development alignment and agile workflow  

**Summary:**  
*Hades*, developed by Supergiant Games, is widely regarded as a model of modern indie game development. Despite its smaller team size and budget, Hades achieved critical acclaim through an **iterative, transparent, and collaborative development process**.

Key success factors included:
- **Tight collaboration between design, art, narrative, and engineering**, with regular feedback loops
- Early and ongoing use of **playable prototypes** to validate mechanics and pacing
- Clear, living documentation for gameplay systems, character dialogue structure, and progression logic
- A deliberately scoped, modular design that allowed gradual content expansion without risking system collapse
- Use of **early access** as a structured feedback and testing phase, enabling the team to refine systems in real time

Unlike large AAA productions, the Hades team did not rely on isolated handoffs or waterfall-style pipelines. Instead, they embraced a **shared responsibility model**, where all departments were involved in shaping and refining the game throughout development.

**Lesson:**  
Hades demonstrates that **small, well-aligned teams with open communication and flexible planning can outperform larger studios** when the workflow encourages iteration, ownership, and cross-discipline collaboration.

## 4. **Cyberpunk 2077 – Broken Integration from Siloed Development**  
**Topic:** Teams worked in parallel without cohesive integration planning  

**Summary:**  
CD Projekt Red developed Cyberpunk 2077 with multiple teams working on quests, AI, open world, and cinematic systems—but in silos. These teams often lacked synchronization, resulting in systems that didn’t align or integrate properly.

**Issues:**  
- AI and quest logic didn't cooperate  
- Mid-project engine upgrades broke existing features  
- QA was brought in late, unable to test systems holistically  

**Lesson:**  
Cross-department collaboration and technical validation are essential throughout development—not just at the end. Integration must be a continuous process.

## 5. **Destiny – Tooling and Team Isolation**  
**Topic:** Technical silos caused by poor documentation and disconnected pipelines  

**Summary:**  
During Destiny's development, different departments at Bungie created custom tools for world-building, scripting, and narrative. These tools were incompatible, and teams lacked shared documentation.

**Issues:**  
- Writers and level designers could not see how content interacted  
- Integration only happened late in production  
- Bugs and mismatches emerged due to isolated testing  

**Lesson:**  
Tool fragmentation is a form of siloing. Cross-functional infrastructure and shared documentation are vital to avoid disconnects.

## 6. **Mass Effect: Andromeda – Lack of Shared Animation Direction**  
**Topic:** Disconnected animation, mocap, and narrative pipelines  

**Summary:**  
Andromeda's awkward facial animations stemmed from narrative, mocap, and animation teams working in isolation. Voice work was recorded before final scripts, and there was no cohesive review process.

**Issues:**  
- Animations looked robotic and lacked emotional tone  
- Scenes lacked consistency across performance layers  
- Rework was minimal due to time pressure and workflow friction  

**Lesson:**  
Narrative-heavy games require real-time collaboration between performance teams. Emotion, timing, and scene context must be shared.

## 7. **Battlefield 2042 – Disconnected Studio Teams and Late QA**  
**Topic:** Cross-studio development with poor synchronization  

**Summary:**  
Battlefield 2042 was developed across multiple global studios. Each worked on isolated systems—vehicles, maps, backend—without aligned testing or documentation standards.

**Issues:**  
- QA joined late and couldn’t test integration properly  
- Features built in silos didn’t mesh (e.g., scale vs. pacing)  
- Bugs and performance issues overwhelmed the launch  

**Lesson:**  
Cross-studio projects demand tight coordination, aligned pipelines, and early QA involvement. Silos at this scale are extremely costly.

## 8. **God of War (2018) – Unified Creative Vision and Technical Collaboration**  
**Studio:** Santa Monica Studio  
**Topic:** Cross-departmental cohesion and long-term planning  

**Summary:**  
God of War's reboot was a massive technical and creative success. The project succeeded because of a **strong creative director (Cory Barlog)**, early alignment between departments, and a clear long-term vision shared by everyone.

**Success Factors:**  
- Cinematic, level, and gameplay teams met regularly  
- The engine team worked closely with animation and camera designers  
- A living design document guided production across all stages  
- Team retrospectives were used frequently to resolve tension and misalignment  

**Lesson:**  
A strong unifying vision and proactive collaboration between disciplines allow for ambitious features (like the no-cut camera) to be executed successfully.
